
-- Examples

-- NOTE : the examples on this file are in reverse chronological order, 
-- 		meaning the most recent additions should be at the top of the file.


--------------------------------------------------------------------------------------------------
-- 
-- Setting the game as a draw
-- added 28/5/04
-------------------------------------------------------------------------------------------------

-- Set the player and win  condition (draw)

	EndRound( -2 )

	

--------------------------------------------------------------------------------------------------
-- 
-- Getting the turn time and updating worm names
-- added 6/2/04
-------------------------------------------------------------------------------------------------

-- The scripts can query the turn time using two functions

	SecsLeft = GetTurnTimeRemaining()
	
	SecsGone = GetTurnTimeExpired()
	
-- Both functions return the time in seconds.
-- Note: These functions will return zero if called outside of a players turn
--	 ( ie hotseat/retreat time, during a reaction/drowning/fall damage animation)


-- To change a worm's name simply change the string in it's data container

	worm = GetWormData( 0 )
	worm.Name = "BadBoy"
	
-- This isn't quite enough though as the graphic name above the worms head
-- needs to be updated. To do this simply call

	UpdateWormNames()
	
-- Note: It is only necessary to call UpdateWormNames() once to update the
--          names of all the worms in the game



--------------------------------------------------------------------------------------------------
-- 
-- Neutral Worms and Moving a worm from one team to another
-- added 28/1/0
-------------------------------------------------------------------------------------------------

-- Neutral worms can be created with the CreateNeutralWorm function. It takes
-- the worm index as an argument,
-- Neutral worms never get a go and are not part of a team. 
-- Neither the AI nor a human can control them in any way.
-- They can have animations run on them and enter/exit phantoms and all the other 
-- normal things worms do, they just never appear in the turn order.
-- They are kind of intended for worms that only appear in cutscenes and can
-- moved in and out of the world as necessary.

	CreateNeutralWorm( 9 )
	
-- It is important that the index given when creating the neutral worm is correct
-- otherwise the game will crash.
-- For example if you had two teams of 4 worms and one neutral

	CreateStandardPlayer("HUMAN",4,"Arthurs","Classic")
	StandardWorm(GetWormData(0),"Arthur","wfRef000")
	StandardWorm(GetWormData(1),"Loyal Knight","wfRef001")    
	StandardWorm(GetWormData(2),"Loyal Knight2","wfRef002")    
	StandardWorm(GetWormData(3),"Chief Architect","wfRef003")
	
	-- worm 4 is the neutral one
	CreateNeutralWorm( 4 )

	-- Player 2's indexes start at 5!
	CreateStandardPlayer("AI",4,"Enemy","Classic")
	StandardWorm(GetWormData(5),"Enemy 1","wfRef004")
	StandardWorm(GetWormData(6),"Enemy 2","wfRef005")    
	StandardWorm(GetWormData(7),"Enemy 3","wfRef006")    
	StandardWorm(GetWormData(8),"Enemy 4","wfRef007")
	
-- if the neutral worm had been created at the end it would have been index 8 and
-- the AI's worms would have been 4 - 7.
	


-- To change the worm a team is on, the ChangeTeamAllegiance function is used. It takes
-- the global worm index and the index of the team the worm is to be on

	-- move worm 5 onto team 1
	ChangeTeamAllegiance( 5, 1 )
	
-- A worm can be placed onto a neutral team by using -1 as the team index

	-- worm 2 becomes neutral
	ChangeTeamAllegiance( 2, -1 )

-- To set up an alliance between player 1 and player 2, and players 0 and 3 are not allied to anyone
-- NB- I think this is how it works, if not, we'll have to check with Sam when we next see him
        GetPlayerData(0).AlliedTeam = 0
        GetPlayerData(1).AlliedTeam = 1
        GetPlayerData(2).AlliedTeam = 1
        GetPlayerData(3).AlliedTeam = 2
        
        
--------------------------------------------------------------------------------------------------
-- 
-- Poisoning Worms
-- added 22/1/0
-------------------------------------------------------------------------------------------------

-- There is now a PoisonWorm function that poisons an individual worm. It takes the 
--  worm index and an amount to poison the worm by per turn

	-- worm 0 is poisioned by 10 health per turn
	PoisonWorm( 0, 10 )


--------------------------------------------------------------------------------------------------
--
-- Checking whether a worm is within a phantom entity
-- added 19/1/04
--------------------------------------------------------------------------------------------------

-- You can check whether a phantom entity contains a particular worm at any time
-- The IsWormWithinPhantom function will return true if the worm is inside the 
-- phantom entity, and false otherwise. It takes the worm index and the name of the
-- phantom.

	-- check is worm 0 is near merlin
	if IsWormWithinPhantom( 0, "pSphereMerlinPhantom" ) == true then
		-- do stuff
	end


---------------------------------------------------------------------------------------------------
--
-- commentary panel changes
--
-- added 9/1/04
---------------------------------------------------------------------------------------------------

-- Script commentary set using SetCommentaryText() should override anything in the
-- commentary queue. 
-- Additionally the queue of commentary items can be deleted using:

FlushCommentaryText()
-- This function will remove all commentary (including script stuff).

--The display of default commentary messages ( tower has been built, grenade selected etc )
-- can be switched on/off using:

-- Only script commentary will be displayed
ShowOnlyScriptCommentary( true )


-- To turn display of non-script back on use the same function with false:

-- Turn default commentary back on
ShowOnlyScriptCommentary( false )

-- Note : ShowOnlyScriptCommentary() will NOT work in the CreatePlayers() function
-- 	    It is safest to call it in HideWormsNow if you want to do it at start up.



----------------------------------------------------------------------------------------------------
--
-- Changing wind on the fly, adding and removing victory locations
--
-- added 5/1/04
----------------------------------------------------------------------------------------------------

-- The wind strength and direction can be changed at any time with the ChangeWind() function
-- it takes two parameters, the wind strength between 0 and 10 and the direction in degrees ( 0 - 360 )

-- set the wind to be strength eight going northwest
ChangeWind( 8,  45)

-- Wind direction 0 is north, east is 270, south is 180 and west is 90.
-- The direction the worms face when first spawned is directly north.


-- Adding and removing victory points

-- To add a victory point to a level use the AddVictoryLocation() function and give it the
-- name of the buildpoint where the victory location will be

-- Add a victory location
AddVictoryLocation( "buildHere001" )

-- Remove a victory location
RemoveVictoryLocation( "buildHere001" )

-- The glowing stars and stuff *should* all work properly, I did test it as much as I (sam) thought necessary
-- I would be interested to know if screws up.
-- Currently there is a maximum amount of victory locations on one level, this is set to 16. If you need more
-- than this you'll have to tell someone. 






--------------------------------------------------------------------------------------------------
--
-- Detail Objects
--
-- added 23/12/03
--------------------------------------------------------------------------------------------------

-- Detail objects can be manipulated in several ways. Currently you can:
--   move them about
--   make them visible or invisible
--   damage them
--   destroy them
--   attach particle emitters to them
--   play their animation clips
-- You can also set up a timer event, which is an action that will take place after a given period of time.

-- Detail Objects Data
-- ===================
-- Each detail object in the game has a data structure which holds various parameters for the object.
-- Most of the time these can be left at their default values, but they can be changed if needed to
-- customise the object. All detail objects are refered to by their unique script name which is set
-- in Maya when the object is placed in the level. Get a detail object's data like this (substituting
-- the object name, obviously):

ObjData = GetDetailObjectData("Tree001")

-- The individual data items can be accessed as follows (the values used in the example are the defaults):

ObjData.IsVisible = true
ObjData.IsCollidable = true
ObjData.CanBeDamaged = true
ObjData.CanBeDestroyed = true
ObjData.DisappearsWhenDestroyed = true
ObjData.TimerEventsAreRepeating = false
ObjData.MovementSpeed = 2.0
ObjData.TimeToReachMovementSpeed = 5.0
ObjData.MaxHealth = 100.0
ObjData.CurrentHealth = 100.0

-- NOTE: Don't change CurrentHealth directly, it will just revert to its propper value. There are functions
--       you can call if you want to damage or destroy a detail object...

-- Damaging And Destroying Detail Objects
-- ======================================
-- To inflict damage on a detail object, simply call the following function and pass in the name of the
-- object and the amount of damage to do. Obviously, if the object's CanBeDamaged data field is set to
-- false, not much will happen!

DamageDetailObject("Tree001", 27)

-- To destroy a detail object in one go, just call this function:

DestroyDetailObject("Tree001")

-- In this case, the data field CanBeDestroyed must be set to true, however, it doesn't matter what CanBeDamaged
-- is set to, it will still get destroyed. If the data field DisappearsWhenDestroyed is set to true, the object
-- will become invisible and non-collidable. This will also happen if the flag is set and you inflict enough
-- damage with DamageDetailObject() to reduce its health to zero.

-- Moving Detail Objects About
-- ===========================
-- You can move a detail object to a named reference point in one of two ways. You can make it move smoothly to
-- its destination or you can make it warp there instantly. When moving smoothly the detail object will travel
-- at the speed which is set in its MovementSpeed data field. It will accelerate from rest up to its movement
-- speed in the time set in its TimeToReachMovementSpeed field, and when it nears its destination it will slow
-- down to rest in the same period of time. The functions to call to move a detail object are:

MoveDetailObjectToPoint("Sheep001", "wfRefGrassyHill")
WarpDetailObjectToPoint("Sheep001", "wfRefGrassyHill")

-- You can find out if a detail object is currently moving like so:

moving = IsDetailObjectMoving("Sheep001")

-- Adding Emitters To Detail Objects
-- =================================
-- Particle emitters can be attached to locator nodes within detail objects. You need to know the name of the
-- locator node (defined in Maya) and also the name of the particle emitter.

AttachEmitterToDetailObject("Sheep001", "PoisonGasCloudEmitter", "wfRefSheepsArse")

-- You can attach more than one particle emitter to a particular locator node in a detail object by simply 
-- calling AttachEmitterToDetailObject with different emitter names.
-- Once attached, you can start and stop emitters by passing in the name of the locator they are attached to.

StartDetailObjectEmitters("Sheep001", "wfRefSheepsArse")
StopDetailObjectEmitters("Sheep001", "wfRefSheepsArse")

-- If you have multiple emitters attached to one node, then the Start and Stop functions will start/stop all 
-- the emitters attached to that node.
-- You can start and stop all the emitters on all locators within a detail object by calling the same functions
-- without specifying a locator name:

StartDetailObjectEmitters("Sheep001")
StopDetailObjectEmitters("Sheep001")

-- Detail Object Animations
-- ========================
-- Detail objects can have animation clips that can be triggered from the script using the following function:

PlayDetailObjectAnimation("Sheep001", "frolicSource")

-- This will cause detail object Sheep001 to play an animation clip called frolicSource. If you want the animation
-- to loop you can pass in "true" as a third parameter (if you omit the third parameter the animation will not loop).

PlayDetailObjectAnimation("Sheep001", "frolicSource", true)

-- Detail objects also have a number of standard animation clips that will play automatically in 
-- certain circumstances provided they are present in the mesh. Currently these are:
--
--   moveSource     : Looped anim played when a detail object is moving (i.e. after MoveDetailObjectToPoint is called)
--   idleSource     : Looped anim played constantly when the object is not doing anything else (e.g. moving)
--   destroySource  : Non-looped anim played when a detail object is destroyed
--
-- If any of these clips are not present in the detail object's mesh then nothing bad will happen, they just won't
-- play.

-- Detail Object Timer Events
-- ==========================
-- You can set up a timer for a detail object which will cause an event to happen after a given period of time
-- has elapsed. The function to set up a timer event has at least three parameters: the name of the detail object,
-- an identifier to specify the event you want to trigger, and a delay (in seconds) until the event happens.

SetDetailObjectTimerEvent("Platform001", kEventSetInvisible, 3)

-- This event will make Platform001 become invisible in 3 seconds time. The list of timer events is as follows:

kEventSetVisible        -- Makes the scenery object visible.
kEventSetInvisible      -- Makes the scenery object invisible.
kEventMoveToPoint       -- Moves the scenery object to a reference point.
kEventWarpToPoint       -- Warps the scenery object to a reference point.
kEventPlayAnimation     -- Plays a named animation clip
kEventNone              -- Does nothing. Triggering this event will cancel any currently set events.

-- Some timer events need more information than the three parameters described above. This is where the fourth
-- optional parameter comes in. For example, to set up a timer event to move or warp an object you must specify
-- where you want it to go. Simply pass in the name of a reference point as the fourth parameter:

SetDetailObjectTimerEvent("Sheep001", kEventMoveToPoint, 5, "wfRefPointSheepDip")

-- You can set up a timer event to play an animation in the same way by using the fourth parameter to specify 
-- the name of the animation clip. Note: The animation will play once and stop. You can't currently trigger
-- looping animations using timer events. The following example will cause detail object Cow001 to play the 
-- animation clip "eatgrassSource" after a 10 second delay. You could make the cow eat grass evey ten seconds
-- by setting the TimerEventsAreRepeating flag to true in the detail object's data (see below).

SetDetailObjectTimerEvent("Cow001", kEventPlayAnimation, 10, "eatgrassSource")

-- This fourth parameter allows the list of timer events to be extended in the future by providing extra data 
-- in any form (number, string, boolean) as and when required.

-- There is a field in the detail objects' data structure called TimerEventsAreRepeating. If this is set to
-- true, then when a timer event occurs the timer will automatically reset to the delay that was specified in
-- the SetTimerEvent() function call. The event will then be triggered again after that amount of time has 
-- elapsed, the timer will then reset again, and so on.

-- DetailObjectCollisionWithWeapon() function
-- If a weapon round collides with a detail object, the script function DetailObjectCollisionWithWeapon() will
-- be called. This function has one parameter, the name of the detail object that was hit. It doesn't return
-- anything to the game.
-- This example would make a detail object visible for 5 seconds when it is hit by a weapon:

function DetailObjectCollisionWithWeapon(ObjectName)

    ObjData = GetDetailObjectData(ObjectName)
    
    ObjData.IsVisible = true
    
    SetDetailObjectTimerEvent(ObjectName, kEventSetInvisible, 5)
end

-- DetailObjectCollisionWithWorm() function
-- Spookily similar to the previous function, but different in that this script function is called when a worm
-- collides with a detail object. It has two parameters: the name of the detail object in question and the index
-- of the worm that hit it. This function does not return a value.

function DetailObjectCollisionWithWorm(ObjectName, WormIndex)

    -- Do something impressive here
    
end

-- DetailObjectDamaged() function
-- This script function is called whenever a detail object is damaged. It has three parameters: the name of the
-- detail object that was damaged, the task id of the thing that damaged it, and the amount of damage that was
-- inflicted. PLEASE NOTE: The task id might be zero if the detail object was damaged from the script (by calling
-- the DamageDetailObject() function), so you should check to make sure it's valid before using it.
-- This example will start any emitters attached to a locator called "LocatorDamageSmoke" if the amount of
-- damage was greater than 20 (if the detail object doesn't have a locator by that name then nothing will happen).

function DetailObjectDamaged(ObjectName, AssailantTaskId, DamageAmount)

    if DamageAmount > 20 then
        StartDetailObjectEmitters(ObjectName, "wfRefDamageSmoke")
    end

end

-- Here's another example. This one gives the detail object a random movement speed and moves it to a randomly 
-- selected reference point if it receives any damage. If it is already moving when it is damaged it will do nothing.

function DetailObjectDamaged(ObjectName, AssailantTaskId, DamageAmount)
	
	IsMoving = IsDetailObjectMoving(ObjectName)
	
	if IsMoving == false then
	
		speed = RandomRange(7)
		
		speed = speed + 3
		
		ObjectData = GetDetailObjectData(ObjectName)
		
		ObjectData.MovementSpeed = speed
		  
		num = RandomRange(6, true)
	      
		if num == 0 then
			dest = "wfRef000"
		elseif num == 1 then
			dest =  "wfRef001"
		elseif num == 2 then
			dest =  "wfRef002"
		elseif num == 3 then
			dest =  "wfRef003"
		elseif num == 4 then
			dest =  "wfRef004"
		elseif num == 5 then
			dest =  "wfRef005"
		end
		    
		MoveDetailObjectToPoint(ObjectName, dest)
	end
        
end




----------------------------------------------------------------------------------------
--
-- Getting and Setting Water Levels, Camera Shake, Explosions and sounds
--
-- added 17/12/03
----------------------------------------------------------------------------------------

-- to get the barrier level call...
BarrierLevel = GetBarrierLevel()

-- to set the barrier level do...
SetBarrierLevel(100)

-- Camera Shake
-- to setup a camera shake call the following
SetCameraShake(15, 25, 3, 7, 0.04, 0, false)

-- the parameters are as follows (in this order)...
-- Total duration (seconds)
-- Speed
-- Lead In time (seconds)
-- Lead Out time (seconds)
-- Max Horizontal Displacement (max movement left-right from centre of cam)
-- Max Vertical Displacement (max movement up-down from centre of cam)
-- Boolean for damping (fades movement at start and end of shake ontop of lead in/out)



-- Explosions - how to script them, make them look pretty and make them go BANG
-- the code to create an ingame explosion looks like this...

Radius = 5
InnerRadius = 2
BuildingDamage = 10
WormDamage = 10
PushForce = 5
CreateExplosion("RefPointName", Radius, InnerRadius, BuildingDamage, WormDamage, PushForce)

-- You could just pass the values straight into the function but for clarity
-- I defined them as variables.

-- The above code will create the logical explosion only - that is it will damage buildings
-- and worms as well as forcing worms away.
-- In order to create a graphical and audio representation keep reading...



-- Creating a Particle Effect in the game
-- to create a particle effect call the following function

EffectId = CreateParticleEffect("Explosion Smoke", "wfRef001")

-- The first parameter is the name of the effect, 
-- the second parameter is the reference point at which the effect will be created.
-- The function will return the Id of the emitter, though you are not required to
-- store this Id you may wish to if creating an infinitely looping effect which
-- you wish to delete at a later point.

-- To delete a Particle/Emitter effect do the following (with the number you
-- previously stored)...

KillParticleEffect(EffectId)



-- Playing (one shot) sound effects
-- to trigger a one shot sound effect do the following...

PlaySound("Weapon.RoundExplode", "wfRef001")
-- the first parameter is the name of the sound effect to trigger, 
-- the second parameter is the name of the reference point where it will be located.


-- The proper explosion effects in the game consist of several elements which all
-- need to be created together. To create an explosion effect with all these elements
-- as well as an explosion sound, use the following function:

CreateExplosionEffects("wfRefExplosion1", kWF_EXPLOSION_MEDIUM, false)

-- The first parameter is the reference point which will be the location of the explosion.
-- The second parameter is the type of explosion. This can be one of:
--
--	kWF_EXPLOSION_SMALL
--	kWF_EXPLOSION_MEDIUM
--	kWF_EXPLOSION_LARGE
--
-- The third parameter is true or false and determines whether the explosion is an 
-- air explosion (no dust/debris) or a ground explosion (with dust/debris). 
-- If you exclude it, it defaults to false (ground explosion).
-- Use this function in conjunction with the logical explosion (CreateExplosion function above)
-- to get a working explosion that looks nice!







--------------------------------------------------------------------
--
-- Buildings Examples
--( 2 / 12 / 03 )
--------------------------------------------------------------------

-- CreateBuilding Example
-- The CreateBuilding function can be called at any time (except initialisation)
-- It requires 3 parameters : a building type , a player index, and a build point
-- So to give player 1 a keep and a tower to defend excalibur -
function defendexcalibur ()
	CreateBuilding( kWF_BUILDING_KEEP, 1, "buildHereExcaliburDefense1" )
	CreateBuilding( kWF_BUILDING_TOWER, 1, "buildHereExcaliburDefense2")
end
-- other (very similar) examples are in Medieval1.lua

-- there is an entirely optional 4th parameter to the CreateBuilding function
-- it should only be used in specific circumstances as it is used to break
-- the game rules regarding buildings having to link back to a stronghold
-- if you want to create a building that doesn't need to link to a stronghold
-- add a fourth parameter on the end set to false:

-- building doesn't need a stronghold!
CreateBuilding( kWF_BUILDING_KEEP, 1, "buildHereExcaliburDefense1", false )
-- this is only intended for special, almost one off, occasions and if you
-- have a number of stronghold-less buildings the game WILL end up doing
-- crazy stuff. The only example where this should be used is Medieval 4 where
-- the player has only one building to shoot from.



--Remove Building example
-- The RemoveBuilding function removes a particular building
-- from the level. It only requires a string with a named build point
RemoveBuilding( "buildHereExcaliburDefense1" )

-- the only other thing to note is that this function just removes
-- the building without the usual camera/ commentary stuff the
-- game normally does for a building being destroyed through
-- weapons fire.


-- Removing all buildings
-- The RemoveAllBuildings function does exactly what it says on the tin
-- it requires no arguments and will not do camera stuff
RemoveAllBuildings()


-- Modifying the health of buildings
-- The health of buildings is generally set in tweak files
-- The ModifyBuildingHealth() function allows you to change
-- the health of a building from the default
-- It requires two arguments, a buildpoint name and a percentage.
-- To decrease the health give a percentage less than 100 and to
-- increase the health a percentage greater than 100.

-- make the excalibur defense weaker ( one fifth of normal health )
ModifyBuildingHealth( "buildHereExcaliburDefense1", 20 )

-- note : currently ( 2 / 12 / 03 ) making the buildings stronger does not work

-- note : if a mission requires you to destroy certain buildings it can make
-- testing quicker to make them dead easy to destroy with this function.


-- New Worm function examples

-- Moving worms
-- Worms can be moved to reference points within the level
-- The MoveWorm function takes three parameters, the global worm index
-- the reference point name and a true/false value that sets the
-- worm on the ground (true) or places him at the exact location of the
-- reference point

-- move worm zero to his start point for chapter 2
MoveWorm( 0, "wfRefWorm0Chapter2", true )

-- In general the third true/false parameter should be set to true.

-- Damaging worms
-- There is a DamageWorm function that applies damage to a worm
-- It takes two parameters, the global index of the worm and the
-- amount of damage to do

-- do worm 0 fifty points of damage
DamageWorm( 0, 50 )


-- Removing and replacing worms

-- HideWorm
-- The HideWorm function removes a worm from view and
-- effectively kills it. It can be replaced later on with the
-- SpawnWorm function.
-- HideWorm takes only one parameter, the global index of the worm
-- to hide.

-- worm zero will be hidden
HideWorm( 0 )

-- to put worm zero back in the level use the SpawnWorm function
-- SpawnWorm takes two parameters, the global worm index and
-- a reference point to place the worm at

-- reanimate worm zero
SpawnWorm( 0, "wfRefBackFromTheDead" )




-- Damaged worm example 

-- WormDamaged() function is called every time a worm is damaged
-- it should return the amount of damage that the worm should take
-- which under normal circumstances is the damage parameter the
-- the function is passed

-- this WormDamaged function would make worm 0 immune
-- to small amounts of damage
function WormDamaged( wormIndex, AssailantTaskId, damage )
	
	if wormIndex == 0 and damage < 10 then
		-- worm 0 takes no damage!
		return 0
	end

	-- every other worm takes damage as normal
	return damage
end


-- this WormDamaged function queries the worm's data container
-- and reduces the amount of damage the less health he has
function WormDamaged( wormIndex, AssailantTaskId, damage )

	worm = GetWormData( wormIndex )
	actualDamage = damage
		
	if worm.Health < 20 then
		-- one fifth of normal damage
		actualDamage = actualDamage * 0.2
	elseif worm.Health < 60 then
		-- half the damage taken
		actualDamage = actualDamage * 0.5
	end

	return actualDamage
end

-- CRATE examples.

-- spawn a normal crate.
-- spawn a crate containing 4 castles at a random location.
SpawnNewCrate(kWF_BUILDING_CASTLE,4,"RANDOM")

-- spawn a health crate, number of contents is the amoutn of health in the crate.
SpawnNewCrate(kWF_UTILITY_HEALTH,45,"RANDOM")

-- spawn a more complex crate.
crate = CreateCrate()
crate.Contents = kWF_BUILDING_CITADEL -- what is in the crate.
crate.NumContents = 3			-- amount in the crate use kWF_INFINITE_AMOUNT for infite
crate.HealthInCrate = -1.0		-- amount of health in a health crate, if set to negative uses the current scheme's CrateHealth
crate.CrateId = 6				-- id only used and set by scripts
crate.TeamDestructible = -1		-- -1 for all teams, otherwise the index of the team
crate.WormCollectable = 5		-- -1 for all worms otherwise the index of the worm
crate.TeamCollectable = 0		-- -1 for all teams, otherwise the index of the team
crate.GroundSnap = true		-- set to true for crate to be placed on the ground below spawn point.
crate.FixedPosition = false		-- set to true, crate will not move i.e. stays at spanw point
crate.UXB = false				-- whether crate is booby trapped
crate.Destructible = true		-- whether crate can be destroyed.
crate.Pushable = false			-- whether crate can be moved by weapons.
crate.CollectableByPayload = false	-- whether crate can be collected by roaming rounds e.g. rhino
crate.Collectable = true		-- whether crate can be collected
SpawnCrate(crate.Index,"RefPointName")

-- trigger crates - special crates which don't use a crate model.
-- spawn as above but
crate.Contents = kWF_TRIGGER_CRATE
crate.Model = "Model name"		-- if you don't set this then the trigger is invisible.

-- when crates are collected CrateCollected is run.
-- the below function kills the worm that collects a speical crate.
function CrateCollected(CrateIndex,WormIndex)
	crate = GetCrateData(CrateIndex)
	worm = GetWormData(WormIndex)
	
	if crate.CrateId == 6 then
		KillWorm(WormIndex)
	end
	collectgarbage()
end

-- when crates are destroyed,
-- the below function hides the worm that destroyed it.
function CrateDestroyed(CrateIndex,WormIndex)
	crate = GetCrateData(CrateIndex)
	worm = GetWormData(WormIndex)
	
	if crate.CrateId == 6 then
		HideWorm(WormIndex)
	end
	collectgarbage()
end

-- when the jetpack runs out of fuel the following
-- function will be called if you have defined it thus
function JetpackFinished()
	-- turn off the tv and do something
	-- less boring instead
end

-- debugging using the Watch() command...

MyVariable = 1
Watch("MyVariable")

-- Using the above only call Watch() once per variable
-- you want to check, preferably just after you've initialised it. 
-- The variable will then be displayed in the red text overlay 
-- (the bit with frames per sec, etc. displayed)
-- The Watch will then handle the rest and the value displayed
-- will magically update when the variables value does, you don't
-- have to go searching round text files for the output!!!

-- You can also use the Watch command to test whether or not
-- some point in the code has been reached by defining a dummy
-- variable and putting the call to Watch in in the code point...

function SomethingOrOther
	IHaveReachedThatPoint = 1
	Watch("IHaveReachedThatPoint")
end

-- in the above example once the function SomethingOrOther gets
-- called you will see: "IHaveReachedThatPoint, 1" on the overlay.

-- Making Buildings Indestructible/Destructible
SetBuildingIndestructible("SomeBuildPoint", true)


--------------------------------------------------------------------------------------------------
--
-- Initialising the Objectives box when pressing the pause options menu
-- added 14/5/04
--------------------------------------------------------------------------------------------------

--the original objectives box works as usual
--for the objectives box when the game is paused you have to initialise it on the start by
--using the function below
--pass in the text ID correspoding to the objectives and the number of objectives

SetObjectives("Miss.Egypt1-Objectives", 3)

--the number of objectives (in this case 3) corresponds to the number of "*" the text has
--The "*" character is at the start of every objective

--every time an objective has been done the function below should be called to denote that

CheckObjective(1)

--the parameter is the index of the objective starting from 0 to 3 (max 4 objectives)
--corresponding to the "*" in the text

--------------------------------------------------------------------------------------------------
--
-- Creating proximity objects to provide the functionality for fire
-- added 25/5/04
--------------------------------------------------------------------------------------------------

-- Creating a fire effect in a level can be done easily by creating a particle emitter
-- at a given reference point. However, this will only give you the graphics. For the
-- fire to repel and damage worms which come too close you need to create a proximity
-- object using the following function:

myfire = CreateProximityObject("wfRefFireLocation", kWF_PROXIMITY_FIRE, 1)

-- The first parameter is the name of a reference point.
-- The second parameter is the type of proximity object.
-- The third parameter is optional, and is the radius of the detection sphere.
-- The function returns a task id which is unique to the new proximity object.

-- A proximity object will only perform the logical function of fire (or even mines).
-- No graphics will be drawn - you are free to spawn the particles of your choice.
-- The type of promitity object will mainly be kWF_PROXIMITY_FIRE, but you can also
-- specify kWF_PROXIMITY_MINE. This will create a proximity object which will trigger
-- if a worm comes too close, and after a short delay anything within range will receive
-- damage. This is perhaps of limited use, as there are no graphics or sound when the
-- 'mine' goes off.

-- The two kinds of proximity object use parameters in the weapons tweak file, namely
-- 'Script Fire' and 'Script Mine'. Most of the parameters are redundant as there is
-- no actual weapon, but if you want to change the damage that the fire does, for example,
-- you can change the GlobalWeaponDamage field. If you call CreateProximityObject with
-- only the first two parameters, the detection radius in the ProximityRoundDetectionRadius
-- field will be used.

-- To remove a proximity object, just pass its task id to the following function:

RemoveProximityObject(myfire)
